@@ -29,7 +29,7 @@ if is_python3:
     import io as StringIO
 else:
     import StringIO
-from . import python_ui_encoder
+from anycodes_python_ui import python_ui_encoder
 
 BREAKPOINT_STR = '#break'
 PYTUTOR_HIDE_STR = '#pythontutor_hide:'
